<?php
if (!function_exists('line_feed')) {
    /**
     * 多行输入框回车换行
     * @param string $str
     * @return string mixed
     */
    function line_feed(string $str): string
    {
        return str_replace("\n", "<br />", $str ?? '');
    }
}

if (!function_exists('str_limit')){
    /**
     * 超出字符省略
     * @param $value
     * @param int $limit
     * @param string $end
     * @return mixed|string
     */
    function str_limit($value, int $limit = 100, string $end = '...'): mixed {
        if (mb_strwidth($value, 'UTF-8') <= $limit) {
            return $value;
        }
        return rtrim(mb_strimwidth($value, 0, $limit, '', 'UTF-8')) . $end;
    }
}

if (!function_exists('str_behind')) {
    /**
     * 获取指定字符之后的数据
     * @param string $str
     * @param string $keyword
     * @return string
     */
    function str_behind(string $str, string $keyword = '')
    {
        $str = explode($keyword, $str);
        if (count($str) < 1) {
            return $str[0];
        }
        $string = '';
        foreach ($str as $key => $val) {
            if ($key === 0) continue;
            $string .= "/{$val}";
        }
        return $string;
    }
}

/**
 * fastadmin site config
 * @param string $key
 * @return false|mixed|Redis|string
 * @throws Exception
 */
if (!function_exists('site')) {
    function site(string $key = '')
    {
        $config = \App\Utils\RedisUtil::getInstance(\App\Master\Enum\RedisKeyEnum::FA_SITE_SETUP)->get();
        if (!$config){
            throw new Exception('fastadmin site config not found');
        }
        $config = json_decode($config,true);
        if (!empty($key)){
            return $config[$key] ?? '';
        }
        return $config;
    }
}

/**
 * 将秒时间转换具体时间:秒转天时分秒
 * @return bool|string
 */
if (!function_exists('time_ext')) {
    function time_ext(int $seconds,int $type = 0,int $min_m = 0): bool|string
    {
        $d = floor($seconds / (3600*24));
        $h = floor(($seconds % (3600*24)) / 3600);
        $m = floor((($seconds % (3600*24)) % 3600) / 60);
        if ($type === 1){
            if($d>'0'){
                $time = "{$d}天{$h}小时{$m}分钟";
            }else{
                if($h!='0'){
                    $time = "{$h}小时{$m}分钟";
                }else{
                    $m = ($min_m === 1 && $m < 1) ? 1 : $m;
                    $time = "{$m}分钟";
                }
            }
        } else {
            if($d>'0'){
                $time = "{$d}d{$h}h{$m}m";
            }else{
                if($h!='0'){
                    $time = "{$h}h{$m}m";
                }else{
                    $m = ($min_m === 1 && $m < 1) ? 1 : $m;
                    $time = "{$m}m";
                }
            }
        }
        return $time;
    }
}

/**
 * 将时间戳转换小时时间
 * @return bool|string
 */
if (!function_exists('time_hour')) {
    function time_hour(int $time): bool|string
    {
        $year = date('Y', $time);
        $month = date('m', $time);
        $day = date('d', $time);

        if ($day == date('d') && $month == date('m') && $year == date('Y')) {
            $times = date('H:i', $time);
        } else {
            $times = date('m-d H:i', $time);
        }

        return $times;
    }
}

if (!function_exists('unix_time')) {
    /**
     * 格式化
     * @param $time
     * @return string
     */
    function unix_time($time): string
    {
        //获取今天凌晨的时间戳
        $day = strtotime(date('Y-m-d', time()));
        //获取昨天凌晨的时间戳
        $pday = strtotime(date('Y-m-d', strtotime('-1 day')));
        //获取现在的时间戳
        $nowtime = time();
        $t       = $nowtime - $time;
        if ($time < $pday) {
            $str = date('m-d', $time);
        } elseif ($time < $day && $time > $pday) {
            $str = "昨天";
        } elseif ($t > 60 * 60) {
            $str = floor($t / (60 * 60)) . "小时前";
        } elseif ($t > 60) {
            $str = floor($t / 60) . "分钟前";
        } else {
            $str = "刚刚";
        }
        return $str;
    }
}

/**
 * 毫秒时间戳
 * @return int
 */
if (!function_exists('ms_time')) {
    function ms_time(): int
    {
        list($ms, $sec) = explode(' ', microtime());
        return intval((floatval($ms) + floatval($sec)) * 1000);
    }
}

/**
 * 获取上传资源的CDN的地址
 * @param string $url 资源相对地址
 * @param bool $ssl
 * @return string
 */
if (!function_exists('cdn_url')) {
    function cdn_url(string $url,bool $ssl = true)
    {
        $regex = "/^((?:[a-z]+:)?\/\/|data:image\/)(.*)/i";
        $cdn_url = \Hyperf\Config\config('cdn_url');

        if (strrpos($url, 'http') !== false || preg_match($regex, $url)) {
            $url = $url;
        } elseif(empty($cdn_url)) {
            $domain = $_SERVER['HTTP_HOST'] ?? '127.0.0.1';
            $http = 'http://';
            $ssl && $http = ((isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') || (isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https')) ? 'https://' : 'http://';
            $url = $http.$domain.$url;
        }else{
            $url = $cdn_url.$url;
        }

        return $url;
    }
}

if (!function_exists('dd')) {
    function dd(...$vars)
    {
        foreach ($vars as $v) {
            var_dump($v);
        }
    }
}