<?php

declare(strict_types=1);

namespace App\Model\Arts;

use App\Master\Enum\RedisKeyEnum;
use App\Model\Model;
use App\Utils\RedisUtil;
use Hyperf\DbConnection\Db;

class UserAddressModel extends Model
{
    /**
     * The table associated with the model.
     *
     * @var ?string
     */
    protected ?string $table = 'user_address';

    protected ?string $dateFormat = 'U';
    public bool       $timestamps = false;

    protected int $is_status_search = 1;// 是否使用 1=是 0=否 默认使用 status = 1 筛选
    protected int $is_delete_search = 0;// 是否使用 1=是 0=否 默认使用 is_delete = 0 筛选

    /**
     * 默认查询字段
     *
     * @var array|string[]
     */
    public array $select = [
        '*'
    ];

    public function searchUserIdAttribute($query, $value, array $params): mixed
    {
        if (!isset($value)) {
            return $query;
        }
        return $query->where('user_id', $value);
    }

    public function dataCreateTimeAttribute($value,$params)
    {
        if (empty($value)){
            return '---';
        }
        return date('Y-m-d H:i:s',$value);
    }

    public static function add(array $params)
    {
        $insert = array_merge($params,[
            'status' => 1,
            'create_time' => time()
        ]);
        return self::query()->insertGetId($insert);
    }

    public static function edit(int $id, array $params)
    {
        unset($params['id']);
        $insert = array_merge($params,[
            'update_time' => time()
        ]);
        $query = self::query()->where('id',$id);

        if (!empty($params['user_id'])){
            $query->where('user_id',$params['user_id']);
        }

        return $query->update($insert);
    }

    public static function del(int $id, int $user_id = 0)
    {
        $insert = [
            'status' => 0,
            'update_time' => time(),
        ];
        $query = self::query()->where('id',$id);

        if (!empty($user_id)){
            $query->where('user_id',$user_id);
        }

        return $query->update($insert);
    }
}
