<?php

declare(strict_types=1);

namespace App\Request\Api\v1\Order;

use Hyperf\Validation\Request\FormRequest;

class SubmitRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     */
    public function rules(): array
    {
        return [
            'type'             => 'required|integer',
            'flight_type'      => 'nullable|integer',
            'point'            => 'required|array',
            'people_num'       => 'nullable|integer',
            'luggage_num'      => 'nullable|integer',
            'is_back'          => 'nullable|integer',
            'is_exclusive'     => 'nullable|integer',
            'appointment_time' => 'nullable|string',
            'pay_type'         => 'required|integer',
            'is_child'         => 'nullable|integer',
            'flight_no'        => 'nullable|string',
            'name'             => 'nullable|string',
            'phone'            => 'nullable|string',
            'remark'           => 'nullable|string',
            'car_seat_id'      => 'nullable|integer',
            'freight_name'      => 'nullable|string',
            'image'      => 'nullable|string',
            'coupon_id' => 'nullable|integer',
            'pay_amount' => 'nullable|decimal:0,2',
        ];
    }

    /**
     * 表单请求后钩子
     * @param $validator
     */
    public function withValidator($validator)
    {
        $validator->after(function ($validator) {
            //获取参数
            $params = $this->validationData();

            if (isset($params['type'])) {
                if ($params['type'] == 20 && empty($params['flight_type'])){
                    return $validator->errors()->add('flight_type', '请输入接送机类型');
                }
                if ($params['type'] == 20 && $params['flight_type'] == 1 && empty($params['flight_no'])){
                    return $validator->errors()->add('flight_no', '请输入航班号');
                }
                if (in_array($params['type'],[10,20]) && empty($params['car_seat_id'])){
                    return $validator->errors()->add('car_seat_id', '请选择车型');
                }
                if ($params['type'] == 50 && empty($params['freight_name'])){
                    return $validator->errors()->add('freight_name', '请填写物品名称');
                }
//                if ($params['type'] == 50 && empty($params['image'])){
//                    return $validator->errors()->add('image', '请上传物品照片');
//                }
            }

            if (!isset($params['point']) || (count($params['point']) < 2 || count($params['point']) > 3)) {
                return $validator->errors()->add('point', '起始点数据有误');
            }

            if (isset($params['point'])) {
                foreach ($params['point'] as $item) {
                    if (empty($item['address']) || empty($item['lng']) || empty($item['lat'])) {
                        $validator->errors()->add('point', '起始点数据有误');
                    }

                    if (!empty($params['type']) && in_array($params['type'], [10, 20]) && empty($item['postal_code'])) {
                        $validator->errors()->add('point', '起始点数据有误');
                    }

                    if ($params['type'] == 50 && (empty($item['name']) || empty($item['phone']))){
                        return $validator->errors()->add('point', '地址数据有误');
                    }
                }
            }

        });
    }
}
