<?php

declare(strict_types=1);

/**
 * This file is part of Hyperf.
 *
 * @link https://www.hyperf.io
 * @document https://doc.hyperf.io
 * @contact group@hyperf.io
 * @license https://github.com/hyperf/hyperf/blob/master/LICENSE
 */

use function Hyperf\Support\env;

return [
    //公众号
    'official_account' => [
        'default' => [
            /**
             * 账号基本信息，请从微信公众平台/开放平台获取
             */
            'app_id'  => env('WECHAT_OFFICIAL_ACCOUNT_APPID', 'your-app-id'),     //AppID
            'secret'  => env('WECHAT_OFFICIAL_ACCOUNT_SECRET', 'your-app-secret'),//AppSecret
            'token'   => env('WECHAT_OFFICIAL_ACCOUNT_TOKEN', 'your-token'),      //Token
            'aes_key' => env('WECHAT_OFFICIAL_ACCOUNT_AES_KEY', ''),              //EncodingAESKey，兼容与安全模式下请一定要填写！！！

            /**
             * OAuth 配置
             *
             * scopes：公众平台（snsapi_userinfo / snsapi_base），开放平台：snsapi_login
             * callback：OAuth授权完成后的回调页地址
             */
            'oauth'   => [
                'scopes'   => ['snsapi_userinfo'],
                'callback' => '/examples/oauth_callback.php',
            ],

            /**
             * 接口请求相关配置，超时时间等，具体可用参数请参考：
             * https://github.com/symfony/symfony/blob/5.3/src/Symfony/Contracts/HttpClient/HttpClientInterface.php
             */
            'http'    => [
                'throw'   => false, // 状态码非 200、300 时是否抛出异常，默认为开启
                'timeout' => 5.0,
                // 'base_uri' => 'https://api.weixin.qq.com/', // 如果你在国外想要覆盖默认的 url 的时候才使用，根据不同的模块配置不同的 uri

                'retry' => true, // 使用默认重试配置
                //  'retry' => [
                //      // 仅以下状态码重试
                //      'http_codes' => [429, 500]
                //       // 最大重试次数
                //      'max_retries' => 3,
                //      // 请求间隔 (毫秒)
                //      'delay' => 1000,
                //      // 如果设置，每次重试的等待时间都会增加这个系数
                //      // (例如. 首次:1000ms; 第二次: 3 * 1000ms; etc.)
                //      'multiplier' => 3
                //  ],
            ],
        ],
    ],

    //支付
    'pay'              => [
        'default' => [
            'mch_id'         => env('WECHAT_PAY_MCH_ID', ''),
            'app_id'         => env('WECHAT_MINI_APP_APPID', ''),

            // 商户证书
            'private_key'    => __DIR__ . '/certs/apiclient_key.pem',
            'certificate'    => __DIR__ . '/certs/apiclient_cert.pem',

            // v3 API 秘钥
            'secret_key'     => env('WECHAT_PAY_SECRET_KEY_V3', ''),

            // v2 API 秘钥
            'v2_secret_key'  => env('WECHAT_PAY_SECRET_KEY_V2', ''),

            // 平台证书：微信支付 APIv3 平台证书，需要使用工具下载
            // 下载工具：https://github.com/wechatpay-apiv3/CertificateDownloader
            'platform_certs' => [
                // '/path/to/wechatpay/cert.pem',
            ],

            /**
             * 接口请求相关配置，超时时间等，具体可用参数请参考：
             * https://github.com/symfony/symfony/blob/5.3/src/Symfony/Contracts/HttpClient/HttpClientInterface.php
             */
            'http'           => [
                'throw'   => false, // 状态码非 200、300 时是否抛出异常，默认为开启
                'timeout' => 5.0,
                // 'base_uri' => 'https://api.mch.weixin.qq.com/', // 如果你在国外想要覆盖默认的 url 的时候才使用，根据不同的模块配置不同的 uri
            ],
        ],
        // ...
    ],

    //小程序
    'mini_app'         => [
        'default' => [
            'app_id'  => env('WECHAT_MINI_APP_APPID', ''),
            'secret'  => env('WECHAT_MINI_APP_SECRET', ''),
            'token'   => env('WECHAT_MINI_APP_TOKEN', 'easywechat'),
            'aes_key' => env('WECHAT_MINI_APP_AES_KEY', '......'),

            /**
             * 接口请求相关配置，超时时间等，具体可用参数请参考：
             * https://github.com/symfony/symfony/blob/5.3/src/Symfony/Contracts/HttpClient/HttpClientInterface.php
             */
            'http'    => [
                'throw'   => false, // 状态码非 200、300 时是否抛出异常，默认为开启
                'timeout' => 5.0,
                // 'base_uri' => 'https://api.weixin.qq.com/', // 如果你在国外想要覆盖默认的 url 的时候才使用，根据不同的模块配置不同的 uri

                'retry' => true, // 使用默认重试配置
                //  'retry' => [
                //      // 仅以下状态码重试
                //      'http_codes' => [429, 500]
                //       // 最大重试次数
                //      'max_retries' => 3,
                //      // 请求间隔 (毫秒)
                //      'delay' => 1000,
                //      // 如果设置，每次重试的等待时间都会增加这个系数
                //      // (例如. 首次:1000ms; 第二次: 3 * 1000ms; etc.)
                //      'multiplier' => 3
                //  ],
            ],
        ],
    ],

    //开放平台
    'open_platform'    => [
        'default' => [
            'app_id'  => env('WECHAT_OPEN_PLATFORM_APPID', 'wx3cf0f39249eb0exx'),                   // 开放平台账号的 appid
            'secret'  => env('WECHAT_OPEN_PLATFORM_SECRET', 'f1c242f4f28f735d4687abb469072axx'),    // 开放平台账号的 secret
            'token'   => env('WECHAT_OPEN_PLATFORM_TOKEN', 'easywechat'),                           // 开放平台账号的 token
            'aes_key' => env('WECHAT_OPEN_PLATFORM_AES_KEY', ''),                                   // 明文模式请勿填写 EncodingAESKey

            /**
             * 接口请求相关配置，超时时间等，具体可用参数请参考：
             * https://github.com/symfony/symfony/blob/5.3/src/Symfony/Contracts/HttpClient/HttpClientInterface.php
             */
            'http'    => [
                'throw'   => false, // 状态码非 200、300 时是否抛出异常，默认为开启
                'timeout' => 5.0,
                // 'base_uri' => 'https://api.weixin.qq.com/', // 如果你在国外想要覆盖默认的 url 的时候才使用，根据不同的模块配置不同的 uri

                'retry' => true, // 使用默认重试配置
                //  'retry' => [
                //      // 仅以下状态码重试
                //      'http_codes' => [429, 500]
                //       // 最大重试次数
                //      'max_retries' => 3,
                //      // 请求间隔 (毫秒)
                //      'delay' => 1000,
                //      // 如果设置，每次重试的等待时间都会增加这个系数
                //      // (例如. 首次:1000ms; 第二次: 3 * 1000ms; etc.)
                //      'multiplier' => 3
                //  ],
            ],
        ],
    ],

    //企业微信
    'work'             => [
        'default' => [
            'corp_id' => env('WECHAT_WORK_CORP_ID', 'wx3cf0f39249eb0exx'),
            'secret'  => env('WECHAT_WORK_SECRET', 'f1c242f4f28f735d4687abb469072axx'),
            'token'   => env('WECHAT_WORK_TOKEN', 'easywechat'),
            'aes_key' => env('WECHAT_WORK_AES_KEY', ''),

            /**
             * 接口请求相关配置，超时时间等，具体可用参数请参考：
             * https://github.com/symfony/symfony/blob/5.3/src/Symfony/Contracts/HttpClient/HttpClientInterface.php
             */
            'http'    => [
                'throw'   => false, // 状态码非 200、300 时是否抛出异常，默认为开启
                'timeout' => 5.0,
                // 'base_uri' => 'https://qyapi.weixin.qq.com/', // 如果你在国外想要覆盖默认的 url 的时候才使用，根据不同的模块配置不同的 uri

                'retry' => true, // 使用默认重试配置
                //  'retry' => [
                //      // 仅以下状态码重试
                //      'http_codes' => [429, 500]
                //       // 最大重试次数
                //      'max_retries' => 3,
                //      // 请求间隔 (毫秒)
                //      'delay' => 1000,
                //      // 如果设置，每次重试的等待时间都会增加这个系数
                //      // (例如. 首次:1000ms; 第二次: 3 * 1000ms; etc.)
                //      'multiplier' => 3
                //  ],
            ],
        ],
    ],

    //企业微信开放平台
    'open_work'        => [
        'default' => [
            'corp_id'         => env('WECHAT_OPEN_WORK_CORP_ID', 'wx3cf0f39249eb0exx'),
            'provider_secret' => env('WECHAT_OPEN_WORK_SECRET', 'f1c242f4f28f735d4687abb469072axx'),
            'token'           => env('WECHAT_OPEN_WORK_TOKEN', 'easywechat'),
            'aes_key'         => env('WECHAT_OPEN_WORK_AES_KEY', ''),// 明文模式请勿填写 EncodingAESKey

            /**
             * 接口请求相关配置，超时时间等，具体可用参数请参考：
             * https://github.com/symfony/symfony/blob/5.3/src/Symfony/Contracts/HttpClient/HttpClientInterface.php
             */
            'http'            => [
                'throw'   => false, // 状态码非 200、300 时是否抛出异常，默认为开启
                'timeout' => 5.0,
                // 'base_uri' => 'https://qyapi.weixin.qq.com/', // 如果你在国外想要覆盖默认的 url 的时候才使用，根据不同的模块配置不同的 uri

                'retry' => true, // 使用默认重试配置
                //  'retry' => [
                //      // 仅以下状态码重试
                //      'http_codes' => [429, 500]
                //       // 最大重试次数
                //      'max_retries' => 3,
                //      // 请求间隔 (毫秒)
                //      'delay' => 1000,
                //      // 如果设置，每次重试的等待时间都会增加这个系数
                //      // (例如. 首次:1000ms; 第二次: 3 * 1000ms; etc.)
                //      'multiplier' => 3
                //  ],
            ],
        ],
    ],
];